@@ -6,8 +6,19 @@ import shutil
 
 import uuid
 
-from mlflow.entities import Experiment, Metric, Param, Run, RunData, RunInfo, RunStatus, RunTag, \
-    ViewType, SourceType, ExperimentTag
+from mlflow.entities import (
+    Experiment,
+    Metric,
+    Param,
+    Run,
+    RunData,
+    RunInfo,
+    RunStatus,
+    RunTag,
+    ViewType,
+    SourceType,
+    ExperimentTag,
+)
 from mlflow.entities.lifecycle_stage import LifecycleStage
 from mlflow.entities.run_info import check_run_is_active, check_run_is_deleted
 from mlflow.exceptions import MlflowException, MissingConfigException
@@ -16,14 +27,35 @@ from mlflow.models import Model
 from mlflow.protos.databricks_pb2 import INTERNAL_ERROR, RESOURCE_DOES_NOT_EXIST
 from mlflow.store.tracking import DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH, SEARCH_MAX_RESULTS_THRESHOLD
 from mlflow.store.tracking.abstract_store import AbstractStore
-from mlflow.utils.validation import _validate_metric_name, _validate_param_name, _validate_run_id, \
-    _validate_tag_name, _validate_experiment_id, \
-    _validate_batch_log_limits, _validate_batch_log_data
+from mlflow.utils.validation import (
+    _validate_metric_name,
+    _validate_param_name,
+    _validate_run_id,
+    _validate_tag_name,
+    _validate_experiment_id,
+    _validate_batch_log_limits,
+    _validate_batch_log_data,
+)
 from mlflow.utils.env import get_env
-from mlflow.utils.file_utils import (is_directory, list_subdirs, mkdir, exists, write_yaml,
-                                     read_yaml, find, read_file_lines, read_file,
-                                     write_to, append_to, make_containing_dirs, mv, get_parent_dir,
-                                     list_all, local_file_uri_to_path, path_to_local_file_uri)
+from mlflow.utils.file_utils import (
+    is_directory,
+    list_subdirs,
+    mkdir,
+    exists,
+    write_yaml,
+    read_yaml,
+    find,
+    read_file_lines,
+    read_file,
+    write_to,
+    append_to,
+    make_containing_dirs,
+    mv,
+    get_parent_dir,
+    list_all,
+    local_file_uri_to_path,
+    path_to_local_file_uri,
+)
 from mlflow.utils.search_utils import SearchUtils
 from mlflow.utils.string_utils import is_string_type
 from mlflow.utils.uri import append_to_uri_path
@@ -41,8 +73,8 @@ def _read_persisted_experiment_dict(experiment_dict):
 
     # 'experiment_id' was changed from int to string, so we must cast to string
     # when reading legacy experiments
-    if isinstance(dict_copy['experiment_id'], int):
-        dict_copy['experiment_id'] = str(dict_copy['experiment_id'])
+    if isinstance(dict_copy["experiment_id"], int):
+        dict_copy["experiment_id"] = str(dict_copy["experiment_id"])
     return Experiment.from_dictionary(dict_copy)
 
 
@@ -50,29 +82,29 @@ def _make_persisted_run_info_dict(run_info):
     # 'tags' was moved from RunInfo to RunData, so we must keep storing it in the meta.yaml for
     # old mlflow versions to read
     run_info_dict = dict(run_info)
-    run_info_dict['tags'] = []
-    run_info_dict['name'] = ''
-    if 'status' in run_info_dict:
+    run_info_dict["tags"] = []
+    run_info_dict["name"] = ""
+    if "status" in run_info_dict:
         # 'status' is stored as an integer enum in meta file, but RunInfo.status field is a string.
         # Convert from string to enum/int before storing.
-        run_info_dict['status'] = RunStatus.from_string(run_info.status)
+        run_info_dict["status"] = RunStatus.from_string(run_info.status)
     else:
-        run_info_dict['status'] = RunStatus.RUNNING
-    run_info_dict['source_type'] = SourceType.LOCAL
-    run_info_dict['source_name'] = ''
-    run_info_dict['entry_point_name'] = ''
-    run_info_dict['source_version'] = ''
+        run_info_dict["status"] = RunStatus.RUNNING
+    run_info_dict["source_type"] = SourceType.LOCAL
+    run_info_dict["source_name"] = ""
+    run_info_dict["entry_point_name"] = ""
+    run_info_dict["source_version"] = ""
     return run_info_dict
 
 
 def _read_persisted_run_info_dict(run_info_dict):
     dict_copy = run_info_dict.copy()
-    if 'lifecycle_stage' not in dict_copy:
-        dict_copy['lifecycle_stage'] = LifecycleStage.ACTIVE
+    if "lifecycle_stage" not in dict_copy:
+        dict_copy["lifecycle_stage"] = LifecycleStage.ACTIVE
     # 'status' is stored as an integer enum in meta file, but RunInfo.status field is a string.
     # converting to string before hydrating RunInfo.
     # If 'status' value not recorded in files, mark it as 'RUNNING' (default)
-    dict_copy['status'] = RunStatus.to_string(run_info_dict.get('status', RunStatus.RUNNING))
+    dict_copy["status"] = RunStatus.to_string(run_info_dict.get("status", RunStatus.RUNNING))
 
     # 'experiment_id' was changed from int to string, so we must cast to string
     # when reading legacy run_infos
@@ -103,9 +135,11 @@ class FileStore(AbstractStore):
         # Create root directory if needed
         if not exists(self.root_directory):
             mkdir(self.root_directory)
-            self._create_experiment_with_id(name=Experiment.DEFAULT_EXPERIMENT_NAME,
-                                            experiment_id=FileStore.DEFAULT_EXPERIMENT_ID,
-                                            artifact_uri=None)
+            self._create_experiment_with_id(
+                name=Experiment.DEFAULT_EXPERIMENT_NAME,
+                experiment_id=FileStore.DEFAULT_EXPERIMENT_ID,
+                artifact_uri=None,
+            )
         # Create trash folder if needed
         if not exists(self.trash_folder):
             mkdir(self.trash_folder)
@@ -130,51 +164,57 @@ class FileStore(AbstractStore):
             if len(exp_list) > 0:
                 return exp_list[0]
         if assert_exists:
-            raise MlflowException('Experiment {} does not exist.'.format(experiment_id),
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Experiment {} does not exist.".format(experiment_id),
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         return None
 
     def _get_run_dir(self, experiment_id, run_uuid):
         _validate_run_id(run_uuid)
         if not self._has_experiment(experiment_id):
             return None
-        return os.path.join(self._get_experiment_path(experiment_id, assert_exists=True),
-                            run_uuid)
+        return os.path.join(self._get_experiment_path(experiment_id, assert_exists=True), run_uuid)
 
     def _get_metric_path(self, experiment_id, run_uuid, metric_key):
         _validate_run_id(run_uuid)
         _validate_metric_name(metric_key)
-        return os.path.join(self._get_run_dir(experiment_id, run_uuid),
-                            FileStore.METRICS_FOLDER_NAME,
-                            metric_key)
+        return os.path.join(
+            self._get_run_dir(experiment_id, run_uuid), FileStore.METRICS_FOLDER_NAME, metric_key
+        )
 
     def _get_param_path(self, experiment_id, run_uuid, param_name):
         _validate_run_id(run_uuid)
         _validate_param_name(param_name)
-        return os.path.join(self._get_run_dir(experiment_id, run_uuid),
-                            FileStore.PARAMS_FOLDER_NAME,
-                            param_name)
+        return os.path.join(
+            self._get_run_dir(experiment_id, run_uuid), FileStore.PARAMS_FOLDER_NAME, param_name
+        )
 
     def _get_experiment_tag_path(self, experiment_id, tag_name):
         _validate_experiment_id(experiment_id)
         _validate_param_name(tag_name)
         if not self._has_experiment(experiment_id):
             return None
-        return os.path.join(self._get_experiment_path(experiment_id, assert_exists=True),
-                            FileStore.TAGS_FOLDER_NAME, tag_name)
+        return os.path.join(
+            self._get_experiment_path(experiment_id, assert_exists=True),
+            FileStore.TAGS_FOLDER_NAME,
+            tag_name,
+        )
 
     def _get_tag_path(self, experiment_id, run_uuid, tag_name):
         _validate_run_id(run_uuid)
         _validate_tag_name(tag_name)
-        return os.path.join(self._get_run_dir(experiment_id, run_uuid), FileStore.TAGS_FOLDER_NAME,
-                            tag_name)
+        return os.path.join(
+            self._get_run_dir(experiment_id, run_uuid), FileStore.TAGS_FOLDER_NAME, tag_name
+        )
 
     def _get_artifact_dir(self, experiment_id, run_uuid):
         _validate_run_id(run_uuid)
         return append_to_uri_path(
             self.get_experiment(experiment_id).artifact_location,
             run_uuid,
-            FileStore.ARTIFACTS_FOLDER_NAME)
+            FileStore.ARTIFACTS_FOLDER_NAME,
+        )
 
     def _get_active_experiments(self, full_path=False):
         exp_list = list_subdirs(self.root_directory, full_path)
@@ -199,28 +239,34 @@ class FileStore(AbstractStore):
                     experiments.append(experiment)
             except MissingConfigException as rnfe:
                 # Trap malformed experiments and log warnings.
-                logging.warning("Malformed experiment '%s'. Detailed error %s",
-                                str(exp_id), str(rnfe), exc_info=True)
+                logging.warning(
+                    "Malformed experiment '%s'. Detailed error %s",
+                    str(exp_id),
+                    str(rnfe),
+                    exc_info=True,
+                )
         return experiments
 
     def _create_experiment_with_id(self, name, experiment_id, artifact_uri):
         artifact_uri = artifact_uri or append_to_uri_path(
-            self.artifact_root_uri, str(experiment_id))
+            self.artifact_root_uri, str(experiment_id)
+        )
         self._check_root_dir()
         meta_dir = mkdir(self.root_directory, str(experiment_id))
         experiment = Experiment(experiment_id, name, artifact_uri, LifecycleStage.ACTIVE)
         experiment_dict = dict(experiment)
         # tags are added to the file system and are not written to this dict on write
         # As such, we should not include them in the meta file.
-        del experiment_dict['tags']
+        del experiment_dict["tags"]
         write_yaml(meta_dir, FileStore.META_DATA_FILE_NAME, experiment_dict)
         return experiment_id
 
     def _validate_experiment_name(self, name):
         """Check the validity of an experiment name."""
         if name is None or name == "":
-            raise MlflowException("Invalid experiment name '%s'" % name,
-                                  databricks_pb2.INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid experiment name '%s'" % name, databricks_pb2.INVALID_PARAMETER_VALUE
+            )
         experiment = self.get_experiment_by_name(name)
         if experiment is not None:
             if experiment.lifecycle_stage == LifecycleStage.DELETED:
@@ -229,17 +275,24 @@ class FileStore(AbstractStore):
                     "You can restore the experiment, or permanently delete the experiment "
                     "from the .trash folder (under tracking server's root folder) in order to "
                     "use this experiment name again." % experiment.name,
-                    databricks_pb2.RESOURCE_ALREADY_EXISTS)
+                    databricks_pb2.RESOURCE_ALREADY_EXISTS,
+                )
             else:
-                raise MlflowException("Experiment '%s' already exists." % experiment.name,
-                                      databricks_pb2.RESOURCE_ALREADY_EXISTS)
+                raise MlflowException(
+                    "Experiment '%s' already exists." % experiment.name,
+                    databricks_pb2.RESOURCE_ALREADY_EXISTS,
+                )
 
     def create_experiment(self, name, artifact_location=None):
         self._check_root_dir()
         self._validate_experiment_name(name)
-        # Get all existing experiments and find the one with largest ID.
+        # Get all existing experiments and find the one with largest numerical ID.
         # len(list_all(..)) would not work when experiments are deleted.
-        experiments_ids = [int(e.experiment_id) for e in self.list_experiments(ViewType.ALL)]
+        experiments_ids = [
+            int(e.experiment_id)
+            for e in self.list_experiments(ViewType.ALL)
+            if e.experiment_id.isdigit()
+        ]
         experiment_id = max(experiments_ids) + 1 if experiments_ids else 0
         return self._create_experiment_with_id(name, str(experiment_id), artifact_location)
 
@@ -251,19 +304,25 @@ class FileStore(AbstractStore):
         _validate_experiment_id(experiment_id)
         experiment_dir = self._get_experiment_path(experiment_id, view_type)
         if experiment_dir is None:
-            raise MlflowException("Could not find experiment with ID %s" % experiment_id,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Could not find experiment with ID %s" % experiment_id,
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         meta = read_yaml(experiment_dir, FileStore.META_DATA_FILE_NAME)
         if experiment_dir.startswith(self.trash_folder):
-            meta['lifecycle_stage'] = LifecycleStage.DELETED
+            meta["lifecycle_stage"] = LifecycleStage.DELETED
         else:
-            meta['lifecycle_stage'] = LifecycleStage.ACTIVE
-        meta['tags'] = self.get_all_experiment_tags(experiment_id)
+            meta["lifecycle_stage"] = LifecycleStage.ACTIVE
+        meta["tags"] = self.get_all_experiment_tags(experiment_id)
         experiment = _read_persisted_experiment_dict(meta)
         if experiment_id != experiment.experiment_id:
-            logging.warning("Experiment ID mismatch for exp %s. ID recorded as '%s' in meta data. "
-                            "Experiment will be ignored.",
-                            experiment_id, experiment.experiment_id, exc_info=True)
+            logging.warning(
+                "Experiment ID mismatch for exp %s. ID recorded as '%s' in meta data. "
+                "Experiment will be ignored.",
+                experiment_id,
+                experiment.experiment_id,
+                exc_info=True,
+            )
             return None
         return experiment
 
@@ -278,28 +337,35 @@ class FileStore(AbstractStore):
         experiment_id = FileStore.DEFAULT_EXPERIMENT_ID if experiment_id is None else experiment_id
         experiment = self._get_experiment(experiment_id)
         if experiment is None:
-            raise MlflowException("Experiment '%s' does not exist." % experiment_id,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Experiment '%s' does not exist." % experiment_id,
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         return experiment
 
     def delete_experiment(self, experiment_id):
         experiment_dir = self._get_experiment_path(experiment_id, ViewType.ACTIVE_ONLY)
         if experiment_dir is None:
-            raise MlflowException("Could not find experiment with ID %s" % experiment_id,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Could not find experiment with ID %s" % experiment_id,
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         mv(experiment_dir, self.trash_folder)
 
     def restore_experiment(self, experiment_id):
         experiment_dir = self._get_experiment_path(experiment_id, ViewType.DELETED_ONLY)
         if experiment_dir is None:
-            raise MlflowException("Could not find deleted experiment with ID %d" % experiment_id,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Could not find deleted experiment with ID %d" % experiment_id,
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         conflict_experiment = self._get_experiment_path(experiment_id, ViewType.ACTIVE_ONLY)
         if conflict_experiment is not None:
             raise MlflowException(
                 "Cannot restore eperiment with ID %d. "
                 "An experiment with same ID already exists." % experiment_id,
-                databricks_pb2.RESOURCE_ALREADY_EXISTS)
+                databricks_pb2.RESOURCE_ALREADY_EXISTS,
+            )
         mv(experiment_dir, self.root_directory)
 
     def rename_experiment(self, experiment_id, new_name):
@@ -307,20 +373,25 @@ class FileStore(AbstractStore):
         # if experiment is malformed, will raise error
         experiment = self._get_experiment(experiment_id)
         if experiment is None:
-            raise MlflowException("Experiment '%s' does not exist." % experiment_id,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Experiment '%s' does not exist." % experiment_id,
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         self._validate_experiment_name(new_name)
         experiment._set_name(new_name)
         if experiment.lifecycle_stage != LifecycleStage.ACTIVE:
-            raise Exception("Cannot rename experiment in non-active lifecycle stage."
-                            " Current stage: %s" % experiment.lifecycle_stage)
+            raise Exception(
+                "Cannot rename experiment in non-active lifecycle stage."
+                " Current stage: %s" % experiment.lifecycle_stage
+            )
         write_yaml(meta_dir, FileStore.META_DATA_FILE_NAME, dict(experiment), overwrite=True)
 
     def delete_run(self, run_id):
         run_info = self._get_run_info(run_id)
         if run_info is None:
-            raise MlflowException("Run '%s' metadata is in invalid state." % run_id,
-                                  databricks_pb2.INVALID_STATE)
+            raise MlflowException(
+                "Run '%s' metadata is in invalid state." % run_id, databricks_pb2.INVALID_STATE
+            )
         check_run_is_active(run_info)
         new_info = run_info._copy_with_overrides(lifecycle_stage=LifecycleStage.DELETED)
         self._overwrite_run_info(new_info)
@@ -335,15 +406,17 @@ class FileStore(AbstractStore):
 
     def _get_deleted_runs(self):
         experiment_ids = self._get_active_experiments() + self._get_deleted_experiments()
-        deleted_runs = self.search_runs(experiment_ids=experiment_ids, filter_string='',
-                                        run_view_type=ViewType.DELETED_ONLY)
+        deleted_runs = self.search_runs(
+            experiment_ids=experiment_ids, filter_string="", run_view_type=ViewType.DELETED_ONLY
+        )
         return [deleted_run.info.run_uuid for deleted_run in deleted_runs]
 
     def restore_run(self, run_id):
         run_info = self._get_run_info(run_id)
         if run_info is None:
-            raise MlflowException("Run '%s' metadata is in invalid state." % run_id,
-                                  databricks_pb2.INVALID_STATE)
+            raise MlflowException(
+                "Run '%s' metadata is in invalid state." % run_id, databricks_pb2.INVALID_STATE
+            )
         check_run_is_deleted(run_info)
         new_info = run_info._copy_with_overrides(lifecycle_stage=LifecycleStage.ACTIVE)
         self._overwrite_run_info(new_info)
@@ -386,19 +459,26 @@ class FileStore(AbstractStore):
             raise MlflowException(
                 "Could not create run under experiment with ID %s - no such experiment "
                 "exists." % experiment_id,
-                databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
         if experiment.lifecycle_stage != LifecycleStage.ACTIVE:
             raise MlflowException(
-                "Could not create run under non-active experiment with ID "
-                "%s." % experiment_id,
-                databricks_pb2.INVALID_STATE)
+                "Could not create run under non-active experiment with ID " "%s." % experiment_id,
+                databricks_pb2.INVALID_STATE,
+            )
         run_uuid = uuid.uuid4().hex
         artifact_uri = self._get_artifact_dir(experiment_id, run_uuid)
-        run_info = RunInfo(run_uuid=run_uuid, run_id=run_uuid, experiment_id=experiment_id,
-                           artifact_uri=artifact_uri, user_id=user_id,
-                           status=RunStatus.to_string(RunStatus.RUNNING),
-                           start_time=start_time, end_time=None,
-                           lifecycle_stage=LifecycleStage.ACTIVE)
+        run_info = RunInfo(
+            run_uuid=run_uuid,
+            run_id=run_uuid,
+            experiment_id=experiment_id,
+            artifact_uri=artifact_uri,
+            user_id=user_id,
+            status=RunStatus.to_string(RunStatus.RUNNING),
+            start_time=start_time,
+            end_time=None,
+            lifecycle_stage=LifecycleStage.ACTIVE,
+        )
         # Persist run metadata and create directories for logging metrics, parameters, artifacts
         run_dir = self._get_run_dir(run_info.experiment_id, run_info.run_id)
         mkdir(run_dir)
@@ -418,8 +498,9 @@ class FileStore(AbstractStore):
         _validate_run_id(run_id)
         run_info = self._get_run_info(run_id)
         if run_info is None:
-            raise MlflowException("Run '%s' metadata is in invalid state." % run_id,
-                                  databricks_pb2.INVALID_STATE)
+            raise MlflowException(
+                "Run '%s' metadata is in invalid state." % run_id, databricks_pb2.INVALID_STATE
+            )
         return self._get_run_from_info(run_info)
 
     def _get_run_from_info(self, run_info):
@@ -434,12 +515,14 @@ class FileStore(AbstractStore):
         """
         exp_id, run_dir = self._find_run_root(run_uuid)
         if run_dir is None:
-            raise MlflowException("Run '%s' not found" % run_uuid,
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "Run '%s' not found" % run_uuid, databricks_pb2.RESOURCE_DOES_NOT_EXIST
+            )
         run_info = self._get_run_info_from_dir(run_dir)
         if run_info.experiment_id != exp_id:
-            raise MlflowException("Run '%s' metadata is in invalid state." % run_uuid,
-                                  databricks_pb2.INVALID_STATE)
+            raise MlflowException(
+                "Run '%s' metadata is in invalid state." % run_uuid, databricks_pb2.INVALID_STATE
+            )
         return run_info
 
     def _get_run_info_from_dir(self, run_dir):
@@ -480,14 +563,17 @@ class FileStore(AbstractStore):
             # When the metric is read back the path will use '\' for separator.
             # We need to translate the path into posix path.
             from mlflow.utils.file_utils import relative_path_to_artifact_path
+
             file_names = [relative_path_to_artifact_path(x) for x in file_names]
         return source_dirs[0], file_names
 
     @staticmethod
     def _get_metric_from_file(parent_path, metric_name):
         _validate_metric_name(metric_name)
-        metric_objs = [FileStore._get_metric_from_line(metric_name, line)
-                       for line in read_file_lines(parent_path, metric_name)]
+        metric_objs = [
+            FileStore._get_metric_from_line(metric_name, line)
+            for line in read_file_lines(parent_path, metric_name)
+        ]
         if len(metric_objs) == 0:
             raise ValueError("Metric '%s' is malformed. No data found." % metric_name)
         # Python performs element-wise comparison of equal-length tuples, ordering them
@@ -512,9 +598,11 @@ class FileStore(AbstractStore):
     def _get_metric_from_line(metric_name, metric_line):
         metric_parts = metric_line.strip().split(" ")
         if len(metric_parts) != 2 and len(metric_parts) != 3:
-            raise MlflowException("Metric '%s' is malformed; persisted metric data contained %s "
-                                  "fields. Expected 2 or 3 fields." %
-                                  (metric_name, len(metric_parts)), databricks_pb2.INTERNAL_ERROR)
+            raise MlflowException(
+                "Metric '%s' is malformed; persisted metric data contained %s "
+                "fields. Expected 2 or 3 fields." % (metric_name, len(metric_parts)),
+                databricks_pb2.INTERNAL_ERROR,
+            )
         ts = int(metric_parts[0])
         val = float(metric_parts[1])
         step = int(metric_parts[2]) if len(metric_parts) == 3 else 0
@@ -530,10 +618,14 @@ class FileStore(AbstractStore):
         parent_path, metric_files = self._get_run_files(run_info, "metric")
         if metric_key not in metric_files:
             run_id = run_info.run_id
-            raise MlflowException("Metric '%s' not found under run '%s'" % (metric_key, run_id),
-                                  databricks_pb2.RESOURCE_DOES_NOT_EXIST)
-        return [FileStore._get_metric_from_line(metric_key, line)
-                for line in read_file_lines(parent_path, metric_key)]
+            raise MlflowException(
+                "Metric '%s' not found under run '%s'" % (metric_key, run_id),
+                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
+            )
+        return [
+            FileStore._get_metric_from_line(metric_key, line)
+            for line in read_file_lines(parent_path, metric_key)
+        ]
 
     @staticmethod
     def _get_param_from_file(parent_path, param_name):
@@ -589,39 +681,51 @@ class FileStore(AbstractStore):
         if not self._has_experiment(experiment_id):
             return []
         experiment_dir = self._get_experiment_path(experiment_id, assert_exists=True)
-        run_dirs = list_all(experiment_dir,
-                            filter_func=lambda x:
-                            all([os.path.basename(os.path.normpath(x)) != reservedFolderName
-                                 for reservedFolderName in
-                                 FileStore.RESERVED_EXPERIMENT_FOLDERS]) and os.path.isdir(x),
-                            full_path=True)
+        run_dirs = list_all(
+            experiment_dir,
+            filter_func=lambda x: all(
+                [
+                    os.path.basename(os.path.normpath(x)) != reservedFolderName
+                    for reservedFolderName in FileStore.RESERVED_EXPERIMENT_FOLDERS
+                ]
+            )
+            and os.path.isdir(x),
+            full_path=True,
+        )
         run_infos = []
         for r_dir in run_dirs:
             try:
                 # trap and warn known issues, will raise unexpected exceptions to caller
                 run_info = self._get_run_info_from_dir(r_dir)
                 if run_info.experiment_id != experiment_id:
-                    logging.warning("Wrong experiment ID (%s) recorded for run '%s'. "
-                                    "It should be %s. Run will be ignored.",
-                                    str(run_info.experiment_id), str(run_info.run_id),
-                                    str(experiment_id), exc_info=True)
+                    logging.warning(
+                        "Wrong experiment ID (%s) recorded for run '%s'. "
+                        "It should be %s. Run will be ignored.",
+                        str(run_info.experiment_id),
+                        str(run_info.run_id),
+                        str(experiment_id),
+                        exc_info=True,
+                    )
                     continue
                 if LifecycleStage.matches_view_type(view_type, run_info.lifecycle_stage):
                     run_infos.append(run_info)
             except MissingConfigException as rnfe:
                 # trap malformed run exception and log warning
                 r_id = os.path.basename(r_dir)
-                logging.warning("Malformed run '%s'. Detailed error %s", r_id, str(rnfe),
-                                exc_info=True)
+                logging.warning(
+                    "Malformed run '%s'. Detailed error %s", r_id, str(rnfe), exc_info=True
+                )
         return run_infos
 
-    def _search_runs(self, experiment_ids, filter_string, run_view_type, max_results, order_by,
-                     page_token):
+    def _search_runs(
+        self, experiment_ids, filter_string, run_view_type, max_results, order_by, page_token
+    ):
         if max_results > SEARCH_MAX_RESULTS_THRESHOLD:
-            raise MlflowException("Invalid value for request parameter max_results. It must be at "
-                                  "most {}, but got value {}".format(SEARCH_MAX_RESULTS_THRESHOLD,
-                                                                     max_results),
-                                  databricks_pb2.INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid value for request parameter max_results. It must be at "
+                "most {}, but got value {}".format(SEARCH_MAX_RESULTS_THRESHOLD, max_results),
+                databricks_pb2.INVALID_PARAMETER_VALUE,
+            )
         runs = []
         for experiment_id in experiment_ids:
             run_infos = self._list_run_infos(experiment_id, run_view_type)
@@ -663,8 +767,11 @@ class FileStore(AbstractStore):
         writeable_param_value = self._writeable_value(param.value)
         if os.path.exists(param_path):
             self._validate_new_param_value(
-                param_path=param_path, param_key=param.key,
-                run_id=run_info.run_id, new_value=writeable_param_value)
+                param_path=param_path,
+                param_key=param.key,
+                run_id=run_info.run_id,
+                new_value=writeable_param_value,
+            )
         make_containing_dirs(param_path)
         write_to(param_path, writeable_param_value)
 
@@ -683,7 +790,8 @@ class FileStore(AbstractStore):
                 "Changing param values is not allowed. Param with key='{}' was already"
                 " logged with value='{}' for run ID='{}'. Attempted logging new value"
                 " '{}'.".format(param_key, current_value, run_id, new_value),
-                databricks_pb2.INVALID_PARAMETER_VALUE)
+                databricks_pb2.INVALID_PARAMETER_VALUE,
+            )
 
     def set_experiment_tag(self, experiment_id, tag):
         """
@@ -695,10 +803,11 @@ class FileStore(AbstractStore):
         _validate_tag_name(tag.key)
         experiment = self.get_experiment(experiment_id)
         if experiment.lifecycle_stage != LifecycleStage.ACTIVE:
-            raise MlflowException("The experiment {} must be in the 'active'"
-                                  "lifecycle_stage to set tags"
-                                  .format(experiment.experiment_id),
-                                  error_code=databricks_pb2.INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "The experiment {} must be in the 'active'"
+                "lifecycle_stage to set tags".format(experiment.experiment_id),
+                error_code=databricks_pb2.INVALID_PARAMETER_VALUE,
+            )
         tag_path = self._get_experiment_tag_path(experiment_id, tag.key)
         make_containing_dirs(tag_path)
         write_to(tag_path, self._writeable_value(tag.value))
@@ -727,8 +836,10 @@ class FileStore(AbstractStore):
         check_run_is_active(run_info)
         tag_path = self._get_tag_path(run_info.experiment_id, run_id, key)
         if not exists(tag_path):
-            raise MlflowException("No tag with name: {} in run with id {}".format(key, run_id),
-                                  error_code=RESOURCE_DOES_NOT_EXIST)
+            raise MlflowException(
+                "No tag with name: {} in run with id {}".format(key, run_id),
+                error_code=RESOURCE_DOES_NOT_EXIST,
+            )
         os.remove(tag_path)
 
     def _overwrite_run_info(self, run_info):
@@ -754,8 +865,11 @@ class FileStore(AbstractStore):
 
     def record_logged_model(self, run_id, mlflow_model):
         if not isinstance(mlflow_model, Model):
-            raise TypeError("Argument 'mlflow_model' should be mlflow.models.Model, got '{}'"
-                            .format(type(mlflow_model)))
+            raise TypeError(
+                "Argument 'mlflow_model' should be mlflow.models.Model, got '{}'".format(
+                    type(mlflow_model)
+                )
+            )
         _validate_run_id(run_id)
         run_info = self._get_run_info(run_id)
         check_run_is_active(run_info)
