@@ -9,14 +9,24 @@ from mlflow.entities import ViewType
 from mlflow.entities.model_registry.model_version_stages import ALL_STAGES
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import FEATURE_DISABLED
-from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.store.model_registry import SEARCH_REGISTERED_MODEL_MAX_RESULTS_DEFAULT
+from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.tracking._model_registry.client import ModelRegistryClient
 from mlflow.tracking._model_registry import utils as registry_utils
-from mlflow.tracking.registry import UnsupportedModelRegistryStoreURIException
 from mlflow.tracking._tracking_service import utils
 from mlflow.tracking._tracking_service.client import TrackingServiceClient
-from mlflow.utils import experimental
+from mlflow.tracking.artifact_utils import _upload_artifacts_to_databricks
+from mlflow.tracking.registry import UnsupportedModelRegistryStoreURIException
+from mlflow.utils.annotations import experimental
+from mlflow.utils.databricks_utils import (
+    is_databricks_default_tracking_uri,
+    is_in_databricks_job,
+    is_in_databricks_notebook,
+    get_workspace_info_from_dbutils,
+    get_workspace_info_from_databricks_secrets,
+)
+from mlflow.utils.logging_utils import eprint
+from mlflow.utils.uri import is_databricks_uri, construct_run_url
 
 _logger = logging.getLogger(__name__)
 
@@ -77,7 +87,8 @@ class MlflowClient(object):
                     "Model Registry features are not supported by the store with URI:"
                     " '{uri}'. Stores with the following URI schemes are supported:"
                     " {schemes}.".format(uri=self._registry_uri, schemes=exc.supported_uri_schemes),
-                    FEATURE_DISABLED)
+                    FEATURE_DISABLED,
+                )
         return registry_client
 
     # Tracking API
@@ -125,9 +136,18 @@ class MlflowClient(object):
         """
         return self._tracking_client.create_run(experiment_id, start_time, tags)
 
-    def list_run_infos(self, experiment_id, run_view_type=ViewType.ACTIVE_ONLY):
+    def list_run_infos(
+        self,
+        experiment_id,
+        run_view_type=ViewType.ACTIVE_ONLY,
+        max_results=SEARCH_MAX_RESULTS_DEFAULT,
+        order_by=None,
+        page_token=None,
+    ):
         """:return: List of :py:class:`mlflow.entities.RunInfo`"""
-        return self._tracking_client.list_run_infos(experiment_id, run_view_type)
+        return self._tracking_client.list_run_infos(
+            experiment_id, run_view_type, max_results, order_by, page_token
+        )
 
     def list_experiments(self, view_type=None):
         """
@@ -325,8 +345,15 @@ class MlflowClient(object):
         """
         self._tracking_client.restore_run(run_id)
 
-    def search_runs(self, experiment_ids, filter_string="", run_view_type=ViewType.ACTIVE_ONLY,
-                    max_results=SEARCH_MAX_RESULTS_DEFAULT, order_by=None, page_token=None):
+    def search_runs(
+        self,
+        experiment_ids,
+        filter_string="",
+        run_view_type=ViewType.ACTIVE_ONLY,
+        max_results=SEARCH_MAX_RESULTS_DEFAULT,
+        order_by=None,
+        page_token=None,
+    ):
         """
         Search experiments that fit the search criteria.
 
@@ -345,25 +372,27 @@ class MlflowClient(object):
             expressions. If the underlying tracking store supports pagination, the token for
             the next page may be obtained via the ``token`` attribute of the returned object.
         """
-        return self._tracking_client.search_runs(experiment_ids, filter_string, run_view_type,
-                                                 max_results, order_by, page_token)
+        return self._tracking_client.search_runs(
+            experiment_ids, filter_string, run_view_type, max_results, order_by, page_token
+        )
 
     # Registry API
 
     # Registered Model Methods
 
     @experimental
-    def create_registered_model(self, name, tags=None):
+    def create_registered_model(self, name, tags=None, description=None):
         """
         Create a new registered model in backend store.
 
         :param name: Name of the new model. This is expected to be unique in the backend store.
         :param tags: A dictionary of key-value pairs that are converted into
                      :py:class:`mlflow.entities.model_registry.RegisteredModelTag` objects.
+        :param description: Description of the model.
         :return: A single object of :py:class:`mlflow.entities.model_registry.RegisteredModel`
                  created by backend.
         """
-        return self._get_registry_client().create_registered_model(name, tags)
+        return self._get_registry_client().create_registered_model(name, tags, description)
 
     @experimental
     def rename_registered_model(self, name, new_name):
@@ -390,8 +419,9 @@ class MlflowClient(object):
         if description is None:
             raise MlflowException("Attempting to update registered model with no new field values.")
 
-        return self._get_registry_client().update_registered_model(name=name,
-                                                                   description=description)
+        return self._get_registry_client().update_registered_model(
+            name=name, description=description
+        )
 
     @experimental
     def delete_registered_model(self, name):
@@ -404,9 +434,9 @@ class MlflowClient(object):
         self._get_registry_client().delete_registered_model(name)
 
     @experimental
-    def list_registered_models(self,
-                               max_results=SEARCH_REGISTERED_MODEL_MAX_RESULTS_DEFAULT,
-                               page_token=None):
+    def list_registered_models(
+        self, max_results=SEARCH_REGISTERED_MODEL_MAX_RESULTS_DEFAULT, page_token=None
+    ):
         """
         List of all registered models
 
@@ -420,15 +450,22 @@ class MlflowClient(object):
         return self._get_registry_client().list_registered_models(max_results, page_token)
 
     @experimental
-    def search_registered_models(self,
-                                 filter_string=None,
-                                 max_results=SEARCH_REGISTERED_MODEL_MAX_RESULTS_DEFAULT,
-                                 order_by=None,
-                                 page_token=None):
+    def search_registered_models(
+        self,
+        filter_string=None,
+        max_results=SEARCH_REGISTERED_MODEL_MAX_RESULTS_DEFAULT,
+        order_by=None,
+        page_token=None,
+    ):
         """
         Search for registered models in backend that satisfy the filter criteria.
 
-        :param filter_string: Filter query string, defaults to searching all registered models.
+        :param filter_string: Filter query string, defaults to searching all registered
+                models. Currently, it supports only a single filter condition as the name
+                of the model, for example, ``name = 'model_name'`` or a search expression
+                to match a pattern in the registered model name.
+                For example, ``name LIKE 'Boston%'`` (case sensitive) or
+                ``name ILIKE '%boston%'`` (case insensitive).
         :param max_results: Maximum number of registered models desired.
         :param order_by: List of column names with ASC|DESC annotation, to be used for ordering
                          matching search results.
@@ -437,9 +474,59 @@ class MlflowClient(object):
         :return: A PagedList of :py:class:`mlflow.entities.model_registry.RegisteredModel` objects
                 that satisfy the search expressions. The pagination token for the next page can be
                 obtained via the ``token`` attribute of the object.
+
+        .. code-block:: python
+            :caption: Example
+
+            import mlflow
+
+            client = mlflow.tracking.MlflowClient()
+
+            # Get search results filtered by the registered model name
+            model_name="CordobaWeatherForecastModel"
+            filter_string = "name='{}'".format(model_name)
+            results = client.search_registered_models(filter_string=filter_string)
+            print("-" * 80)
+            for res in results:
+                for mv in res.latest_versions:
+                    print("name={}; run_id={}; version={}".format(mv.name, mv.run_id, mv.version))
+
+            # Get search results filtered by the registered model name that matches
+            # prefix pattern
+            filter_string = "name LIKE 'Boston%'"
+            results = client.search_registered_models(filter_string=filter_string)
+            for res in results:
+                for mv in res.latest_versions:
+                print("name={}; run_id={}; version={}".format(mv.name, mv.run_id, mv.version))
+
+            # Get all registered models and order them by ascending order of the names
+            results = client.search_registered_models(order_by=["name ASC"])
+            print("-" * 80)
+            for res in results:
+                for mv in res.latest_versions:
+                    print("name={}; run_id={}; version={}".format(mv.name, mv.run_id, mv.version))
+
+        .. code-block:: text
+            :caption: Output
+
+            ------------------------------------------------------------------------------------
+            name=CordobaWeatherForecastModel; run_id=eaef868ee3d14d10b4299c4c81ba8814; version=1
+            name=CordobaWeatherForecastModel; run_id=e14afa2f47a040728060c1699968fd43; version=2
+            ------------------------------------------------------------------------------------
+            name=BostonWeatherForecastModel; run_id=ddc51b9407a54b2bb795c8d680e63ff6; version=1
+            name=BostonWeatherForecastModel; run_id=48ac94350fba40639a993e1b3d4c185d; version=2
+            -----------------------------------------------------------------------------------
+            name=AzureWeatherForecastModel; run_id=5fcec6c4f1c947fc9295fef3fa21e52d; version=1
+            name=AzureWeatherForecastModel; run_id=8198cb997692417abcdeb62e99052260; version=3
+            name=BostonWeatherForecastModel; run_id=ddc51b9407a54b2bb795c8d680e63ff6; version=1
+            name=BostonWeatherForecastModel; run_id=48ac94350fba40639a993e1b3d4c185d; version=2
+            name=CordobaWeatherForecastModel; run_id=eaef868ee3d14d10b4299c4c81ba8814; version=1
+            name=CordobaWeatherForecastModel; run_id=e14afa2f47a040728060c1699968fd43; version=2
+
         """
-        return self._get_registry_client().search_registered_models(filter_string, max_results,
-                                                                    order_by, page_token)
+        return self._get_registry_client().search_registered_models(
+            filter_string, max_results, order_by, page_token
+        )
 
     @experimental
     def get_registered_model(self, name):
@@ -488,19 +575,78 @@ class MlflowClient(object):
     # Model Version Methods
 
     @experimental
-    def create_model_version(self, name, source, run_id, tags=None):
+    def create_model_version(
+        self, name, source, run_id, tags=None, run_link=None, description=None
+    ):
         """
-        Create a new model version from given source or run ID.
+        Create a new model version from given source (artifact URI).
 
-        :param name: Name ID for containing registered model.
+        :param name: Name for the containing registered model.
         :param source: Source path where the MLflow model is stored.
         :param run_id: Run ID from MLflow tracking server that generated the model
         :param tags: A dictionary of key-value pairs that are converted into
                      :py:class:`mlflow.entities.model_registry.ModelVersionTag` objects.
+        :param run_link: Link to the run from an MLflow tracking server that generated this model.
+        :param description: Description of the version.
         :return: Single :py:class:`mlflow.entities.model_registry.ModelVersion` object created by
                  backend.
         """
-        return self._get_registry_client().create_model_version(name, source, run_id, tags)
+        tracking_uri = self._tracking_client.tracking_uri
+        if not run_link and is_databricks_uri(tracking_uri) and tracking_uri != self._registry_uri:
+            run_link = self._get_run_link(tracking_uri, run_id)
+        new_source = source
+        if is_databricks_uri(self._registry_uri) and tracking_uri != self._registry_uri:
+            # Print out some info for user since the copy may take a while for large models.
+            eprint(
+                "=== Copying model files from the source location to the model"
+                + " registry workspace ==="
+            )
+            new_source = _upload_artifacts_to_databricks(
+                source, run_id, tracking_uri, self._registry_uri
+            )
+            # NOTE: we can't easily delete the target temp location due to the async nature
+            # of the model version creation - printing to let the user know.
+            eprint(
+                "=== Source model files were copied to %s" % new_source
+                + " in the model registry workspace. You may want to delete the files once the"
+                + " model version is in 'READY' status. You can also find this location in the"
+                + " `source` field of the created model version. ==="
+            )
+        return self._get_registry_client().create_model_version(
+            name=name,
+            source=new_source,
+            run_id=run_id,
+            tags=tags,
+            run_link=run_link,
+            description=description,
+        )
+
+    def _get_run_link(self, tracking_uri, run_id):
+        # if using the default Databricks tracking URI and in a notebook, we can automatically
+        # figure out the run-link.
+        if is_databricks_default_tracking_uri(tracking_uri) and (
+            is_in_databricks_notebook() or is_in_databricks_job()
+        ):
+            # use DBUtils to determine workspace information.
+            workspace_host, workspace_id = get_workspace_info_from_dbutils()
+        else:
+            # in this scenario, we're not able to automatically extract the workspace ID
+            # to proceed, and users will need to pass in a databricks profile with the scheme:
+            # databricks://scope:prefix and store the host and workspace-ID as a secret in the
+            # Databricks Secret Manager with scope=<scope> and key=<prefix>-workspaceid.
+            workspace_host, workspace_id = get_workspace_info_from_databricks_secrets(tracking_uri)
+            if not workspace_id:
+                print(
+                    "No workspace ID specified; if your Databricks workspaces share the same"
+                    " host URL, you may want to specify the workspace ID (along with the host"
+                    " information in the secret manager) for run lineage tracking. For more"
+                    " details on how to specify this information in the secret manager,"
+                    " please refer to the model registry documentation."
+                )
+        # retrieve experiment ID of the run for the URL
+        experiment_id = self.get_run(run_id).info.experiment_id
+        if workspace_host and run_id and experiment_id:
+            return construct_run_url(workspace_host, experiment_id, run_id, workspace_id)
 
     @experimental
     def update_model_version(self, name, version, description=None):
@@ -516,8 +662,9 @@ class MlflowClient(object):
         if description is None:
             raise MlflowException("Attempting to update model version with no new field values.")
 
-        return self._get_registry_client().update_model_version(name=name, version=version,
-                                                                description=description)
+        return self._get_registry_client().update_model_version(
+            name=name, version=version, description=description
+        )
 
     @experimental
     def transition_model_version_stage(self, name, version, stage, archive_existing_versions=False):
@@ -572,10 +719,42 @@ class MlflowClient(object):
         """
         Search for model versions in backend that satisfy the filter criteria.
 
-        :param filter_string: A filter string expression. Currently supports a single filter
-                              condition either name of model like ``name = 'model_name'`` or
+        :param filter_string: A filter string expression. Currently, it supports a single filter
+                              condition either a name of model like ``name = 'model_name'`` or
                               ``run_id = '...'``.
         :return: PagedList of :py:class:`mlflow.entities.model_registry.ModelVersion` objects.
+
+        .. code-block:: python
+            :caption: Example
+
+            import mlflow
+
+            client = mlflow.tracking.MlflowClient()
+
+            # Get all versions of the model filtered by name
+            model_name = "CordobaWeatherForecastModel"
+            filter_string = "name='{}'".format(model_name)
+            results = client.search_model_versions(filter_string)
+            print("-" * 80)
+            for res in results:
+                print("name={}; run_id={}; version={}".format(res.name, res.run_id, res.version))
+
+            # Get the version of the model filtered by run_id
+            run_id = "e14afa2f47a040728060c1699968fd43"
+            filter_string = "run_id='{}'".format(run_id)
+            results = client.search_model_versions(filter_string)
+            print("-" * 80)
+            for res in results:
+                print("name={}; run_id={}; version={}".format(res.name, res.run_id, res.version))
+
+        .. code-block:: text
+            :caption: Output
+
+            ------------------------------------------------------------------------------------
+            name=CordobaWeatherForecastModel; run_id=eaef868ee3d14d10b4299c4c81ba8814; version=1
+            name=CordobaWeatherForecastModel; run_id=e14afa2f47a040728060c1699968fd43; version=2
+            ------------------------------------------------------------------------------------
+            name=CordobaWeatherForecastModel; run_id=e14afa2f47a040728060c1699968fd43; version=2
         """
         return self._get_registry_client().search_model_versions(filter_string)
 
